package cn.reghao.tnb.sb.multi.mybatis.mapper.two;

import cn.reghao.tnb.sb.multi.mybatis.model.two.ImagePost;
import cn.reghao.jutil.jdk.web.db.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @author reghao
 * @date 2023-08-19 02:33:11
 */
@Mapper
public interface ImagePostMapper extends BaseMapper<ImagePost> {
    void updateUserId(@Param("oldUser") long oldUser, @Param("newUser") long newUser);

    ImagePost findImagePost(long albumId);
    List<ImagePost> findImagePostByUserId(long userId);
    List<Long> findImageUser();
    List<Long> findVideoUser();
}
